@@ -2,6 +2,8 @@
 Routines for averaging 2D and 3D images
 in polar and spherical coordinates.
 
+Adapted from aziavg.py in https://github.com/davidgrier/dgmath/.
+
 .. moduleauthor:: Michael O'Brien <michaelobrien@g.harvard.edu>
 
 """
@@ -15,40 +17,38 @@ def radialavg(data, center=None, dphi=None,
     """
     Average data over bins of radial contours.
 
-    Adapted from aziavg.py in https://github.com/davidgrier/dgmath/
-
     Parameters
     ----------
-    data : np.ndarray
+    data : `np.ndarray`
         Two-dimensional data array.
-    center : tuple, shape (2,), optional
+    center : `tuple`, shape `(2,)`, optional
         (x, y) coordinates of the point around which to compute average.
         Default is the image's geometric center.
-    dphi : float, optional
+    dphi : `float`, optional
         Angular division of bins on which to group angles when
         averaging.
-    bounds : tuple int, optional
-        Anglular range of average. The default is (0, 2*pi)
-    portion : bool, optional
+    bounds : `tuple`, shape `(2,)`, optional
+        Anglular range of average. The default is ``(0, 2*np.pi)``.
+    portion : `bool`, optional
         Choose whether to scale data according to position in bin.
         Good for small number of bins and a lot of data.
-    stdev : bool, optional
+    stdev : `bool`, optional
         Choose whether to return error bars for each bin.
         Only works for portion equal to False.
-    avg : bool, optional
+    avg : `bool`, optional
         Choose whether to average data along radial contours
         or compute sum.
-    weight : np.ndarray, optional
+    weight : `np.ndarray`, optional
         Relative weighting of each pixel in data.
         The default weighting is uniform.
 
     Returns
     -------
-    result : np.ndarray
+    result : `np.ndarray`
         One-dimensional radial average.
-    phin : np.ndarray
+    phin : `np.ndarray`
         The bins of angles.
-    stdev : np.ndarray, optional
+    stdev : `np.ndarray`, optional
         Standard deviations from the average.
     """
     y, x = np.indices(data.shape)
@@ -140,40 +140,38 @@ def aziavg(data, center=None, rad=None,
     '''
     Average data over bins of azimuthal contours.
 
-    Extension of aziavg.py in https://github.com/davidgrier/dgmath/
-
     Parameters
     ----------
-    data : np.ndarray
-        two-dimensional data array.
-    center : tuple, shape (2,), optional
+    data : `np.ndarray`
+        Two-dimensional data array.
+    center : `tuple`, shape `(2,)`, optional
         (x, y) coordinates of the point around which to compute average.
         Default is the image's geometric center.
-    rad : np.ndarray or int, optional
+    rad : `np.ndarray` or `int`, optional
         Array of bins to use in average or maximum radius.
         of average.
         The default is half of the minimum dimension of the data.
-    portion : bool, optional
+    portion : `bool`, optional
         Choose whether to portion data by position in bin.
         Good for small number of bins compared to dimension
         of data.
-    stdev : bool, optional
+    stdev : `bool`, optional
         Choose whether to return error bars for each bin.
         Only works for portion equal to False.
-    avg : bool, optional
+    avg : `bool`, optional
         Choose whether to average data along azimuthal contours
         or to compute sum.
-    weight : np.ndarray, optional
+    weight : `np.ndarray`, optional
         Relative weighting of each pixel in data.
         The default weighting is uniform.
 
     Returns
     -------
-    result : np.ndarray
+    result : `np.ndarray`
         One-dimensional azimuthal average.
-    rn : np.ndarray
+    rn : `np.ndarray`
         Radial bins of average.
-    stdev : np.ndarray, optional
+    stdev : `np.ndarray`, optional
         Standard deviations from the average.
     '''
     y, x = np.indices(data.shape)
@@ -247,38 +245,36 @@ def shellavg(data, center=None, rad=None,
     """
     Average data over bins of spherical shells.
 
-    Adapted from aziavg.py in https://github.com/davidgrier/dgmath/
-
     Parameters
     ----------
-    data : ndarray
+    data : `np.ndarray`
         Three-dimensional data array.
-    center : tuple, shape (3,), optional
+    center : `tuple`, shape `(3,)`, optional
         (x, y, z) coordinates of the point around which to compute average.
         Default is the image's geometric center.
-    rad : np.ndarray or int, optional
-        array of bins to use in average or
-        maximum radius of average [pixels]
-        Default: half of the minimum dimension of the data
-    portion : bool, optional
+    rad : `np.ndarray` or `int`, optional
+        Array of bins to use in average or
+        maximum radius of average.
+        Default: half of the minimum dimension of the data.
+    portion : `bool`, optional
         Choose whether to scale data according to position in bin.
         Good for small number of bins and a lot of data.
-    stdev : bool, optional
+    stdev : `bool`, optional
         Choose whether to return error bars for each bin.
         Only works for portion equal to False.
-    avg : bool, optional
+    avg : `bool`, optional
         Choose whether to average data along shells or compute sum.
-    weight : ndarray, optional
+    weight : `np.ndarray`, optional
         Relative weighting of each pixel in data.
         The default weighting is uniform.
 
     Returns
     -------
-    result : np.ndarray
+    result : `np.ndarray`
         One-dimensional angular average.
-    rn : np.ndarray
+    rn : `np.ndarray`
         Radial bins of the average.
-    stdev : ndarray, optional
+    stdev : `np.ndarray`, optional
         Standard deviations from the average.
     """
     z, y, x = np.indices(data.shape)
